﻿<?xml version="1.0"?>

<!-- 
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ 
	(c) Thomas Mikscha
		thomas.mikscha@gmail.com
	
	Changes 
	2013/11/10 TM: Initial version
	
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0">
  <xsl:output method="html" version="2.0" encoding="utf-8" omit-xml-declaration="yes" indent="no" media-type="text/html"/>


  <xsl:template match="/">

    <xsl:variable name="recs_tweets" select="/report/Tweets/Tweet"/>
    <xsl:variable name="max_followers">
      <xsl:for-each select="$recs_tweets">
        <xsl:sort select="user_followerscount" data-type="number" order="descending"/>

        <xsl:if test="position()=1">
          <xsl:value-of select="user_followerscount"/>
        </xsl:if>
      </xsl:for-each>
    </xsl:variable>

    <xsl:variable name="min_followers">
      <xsl:for-each select="$recs_tweets">
        <xsl:sort select="user_followerscount" data-type="number" order="ascending"/>

        <xsl:if test="position()=1">
          <xsl:value-of select="user_followerscount"/>
        </xsl:if>
      </xsl:for-each>
    </xsl:variable>

    <xsl:variable name="avg_followers" select="sum($recs_tweets/user_followerscount[.!='']) div count($recs_tweets)"/>

    <html xmlns="http://www.w3.org/1999/xhtml">
      <head>
        <style type="text/css">
          table.hovertable {
          font-family: verdana,arial,sans-serif;
          font-size:11px;
          color:#333333;
          border-width: 1px;
          border-color: #999999;
          border-collapse: collapse;
          }
          table.hovertable th {
          background-color:#c3dde0;
          border-width: 1px;
          padding: 8px;
          border-style: solid;
          border-color: #a9c6c9;
          }
          table.hovertable tr {
          background-color:#d4e3e5;
          }
          table.hovertable td {
          border-width: 1px;
          padding: 8px;
          border-style: solid;
          border-color: #a9c6c9;
          }
        </style>
      </head>
      <body>
        <xsl:variable name="cpy" select="$recs_tweets[1]"/>
        <xsl:variable name="name" select="$cpy/company_name"/>
        <xsl:variable name="email" select="$cpy/email_address"/>
        <xsl:variable name="keyword" select="$cpy/keyword"/>
        <xsl:variable name="count_negative" select="count($recs_tweets[classification = 0])"/>
        <xsl:variable name="count_positive" select="count($recs_tweets[classification = 1])"/>
        <xsl:variable name="count_total_tweets" select="count($recs_tweets)"/>
        <xsl:variable name="negative_perc" select="(round($count_negative * 10000) div $count_total_tweets) div 100"/>
        <xsl:variable name="positive_perc" select="(round($count_positive * 10000) div $count_total_tweets) div 100"/>

		<xsl:variable name="neg_sentiments_weigthed">
			<xsl:call-template name="CalcWeightedSum">     
				<xsl:with-param name="nodes" select="$recs_tweets[classification = 0]"/>     
				<xsl:with-param name="sum" select="0" />   
				<xsl:with-param name="avg_followers" select="$avg_followers" />
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:variable name="pos_sentiments_weigthed">
			<xsl:call-template name="CalcWeightedSum">     
				<xsl:with-param name="nodes" select="$recs_tweets[classification = 1]"/>     
				<xsl:with-param name="sum" select="0" />   
				<xsl:with-param name="avg_followers" select="$avg_followers" />
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:variable name="all_sentiments_weigthed">
			<xsl:call-template name="CalcWeightedSum">     
				<xsl:with-param name="nodes" select="$recs_tweets"/>     
				<xsl:with-param name="sum" select="0" />   
				<xsl:with-param name="avg_followers" select="$avg_followers" />
			</xsl:call-template>
		</xsl:variable>
	
	
        <table class="hovertable">
          <tr>
            <th rowspan="2">Company</th>
            <th rowspan="2">Email</th>
            <th rowspan="2">Keyword</th>
            <th colspan="2">Sentiment</th>
            <th colspan="2">Sentiment (Weighted)</th>
          </tr>
          <tr>
            <th>Positive</th>
            <th>Negative</th>
			<th>Positive</th>
            <th>Negative</th>
          </tr>
          <tr>
            <td style="text-align: left;">
              <xsl:value-of select="$name"/>
            </td>
            <td style="text-align: left;">
              <xsl:value-of select="$email"/>
            </td>
            <td style="text-align: left;">
              <xsl:value-of select="$keyword"/>
            </td>

            <td style="text-align: right;">
              <xsl:value-of select="$positive_perc"/>%
            </td>
            <td style="text-align: right;">
              <xsl:value-of select="$negative_perc"/>%
            </td>
			
			<td style="text-align: right;">
              <xsl:value-of select="(($pos_sentiments_weigthed div $all_sentiments_weigthed) * 10000) div 100"/>%
            </td>
            <td style="text-align: right;">
              <xsl:value-of select="(($neg_sentiments_weigthed div $all_sentiments_weigthed) * 10000) div 100"/>%
            </td>
          </tr>
        </table>
        <br/>
        <table class="hovertable">
          <tr>
            <th>User name</th>
            <th>Followers</th>
            <th>Weighting</th>
            <th>Weighting %</th>
            <th>Classification</th>
            <th>Avg Followers</th>
            <th>Text (Orig.)</th>
            <th>Text (Processed)</th>
          </tr>
          <xsl:for-each select="$recs_tweets">
            <xsl:sort select="user_followerscount" data-type="number" order="descending"/>
            <xsl:variable name="followers" select="user_followerscount"/>
            <xsl:variable name="weighting" select="$followers div $avg_followers"/>
            <xsl:variable name="username" select="user_name"/>
            <xsl:variable name="classification" select="classification"/>
            <xsl:variable name="weighting_perc" select="(round($weighting * 100 * 100) div 100)"/>
            <xsl:variable name="text" select="text"/>
            <xsl:variable name="text_processed" select="text_processed"/>

            <tr onmouseover="this.style.backgroundColor='#ffff66';" onmouseout="this.style.backgroundColor='#d4e3e5';">
              <td>
                <xsl:value-of select="$username"/>
              </td>
              <td style="text-align: right;">
                <xsl:value-of select="$followers"/>
              </td>
			  
			  <td style="text-align: right;">
                <xsl:value-of select="$weighting"/>
              </td>
              <td style="text-align: right;">
                <xsl:value-of select="concat($weighting_perc,'%')"/>
              </td>
              <td style="text-align: right;">
                <xsl:value-of select="$classification"/>
              </td>
			  <td style="text-align: right;">
                <xsl:value-of select="$avg_followers"/>
              </td>
              <td style="text-align: left;">
                <xsl:value-of select="$text"/>
              </td>
              <td style="text-align: left;">
                <xsl:value-of select="$text_processed"/>
              </td>
			  
			  
			  
            </tr>
          </xsl:for-each>
        </table>
      </body>
    </html>
  </xsl:template>
  
  <xsl:template name="CalcWeightedSum">     
	<xsl:param name="nodes" />     
	<xsl:param name="sum"  />   
	<xsl:param name="avg_followers"/>

	<xsl:variable name="curr_item" select="$nodes[1]"/>
	<xsl:variable name="followers" select="sum($curr_item/user_followerscount[.!=''])"/>
	<xsl:variable name="weighting" select="number($followers) div number($avg_followers)"/>
	
	
	<xsl:if test="$curr_item">        
		<xsl:call-template name="CalcWeightedSum">         
			<xsl:with-param name="nodes" select="$nodes[position() &gt; 1]" />         
			<xsl:with-param name="sum" select="$sum + $weighting" />       
			<xsl:with-param name="avg_followers" select="$avg_followers" />       
		</xsl:call-template>   
	</xsl:if>
	
	<xsl:if test="not($curr_item)">       
		<xsl:value-of select="$sum" />     
	</xsl:if>

</xsl:template>

</xsl:stylesheet>